@@ -452,7 +452,9 @@ class Export:
         # Note, having zero annotates can still be considered annotated
         # in cases when are no objects in the image thats should be indentified
         yolo_dataset = yolo_dataset.loc[yolo_dataset["annotated"] == 1]
-        yolo_dataset["cat_id"] = yolo_dataset["cat_id"].astype(pd.Int32Dtype())
+        yolo_dataset["cat_id"] = (
+            yolo_dataset["cat_id"].astype("float").astype(pd.Int32Dtype())
+        )
 
         if cat_id_index != None:
             assert isinstance(cat_id_index, int), "cat_id_index must be an int."
@@ -691,9 +693,9 @@ class Export:
         mergedA = pd.concat(df_outputA, ignore_index=True)
         mergedC = pd.concat(df_outputC, ignore_index=True)
 
-        resultI = mergedI[0].to_json(orient="split")
-        resultA = mergedA[0].to_json(orient="split")
-        resultC = mergedC[0].to_json(orient="split")
+        resultI = mergedI[0].to_json(orient="split", default_handler=str)
+        resultA = mergedA[0].to_json(orient="split", default_handler=str)
+        resultC = mergedC[0].to_json(orient="split", default_handler=str)
 
         parsedI = json.loads(resultI)
         del parsedI["index"]
